/*************************************************  Device Functions Header  **************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	Copyright 2014, Red Rapids, Inc.

*************************************************  Device Functions Header  **************************************************/

#ifndef _DEVICE_FUNCTIONS_H_
#define _DEVICE_FUNCTIONS_H_

#if defined(__cplusplus)
	extern "C" {
#endif

// Structure to store configuration register settings for the AD9512 clock distribution chip.
typedef struct
{
	unsigned long Payload[22][2];
} s_AD9512;

// Structure to store configuration register settings for the ADC08D1520 ADC chip.
typedef struct
{
	unsigned long Payload[11][2];
} s_ADC12D1600;

// Structure to store configuration settings for the ADF4110 synthesizer chip.
typedef struct
{
	unsigned long A;
	unsigned long B;
} s_ADF4110;

// Structure to set the two enable bits on the ADL5566 amplifier chip.
typedef struct
{
	unsigned long Enable[2][2];
} s_ADL5566;

// Structure to store configuration register settings for the ADS42LB69 ADC chip.
typedef struct
{
	unsigned long Payload[21][2];
} s_ADS42LB69;

// Structure to store configuration register settings for the LTC1661 DAC chip.
typedef struct
{
	unsigned long Payload[8][2];
} s_LTC1661;

// Prototypes for each of the device functions.
unsigned long AD9512Read(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address);
unsigned long AD9512Write(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address, unsigned long Data);
unsigned long ADC12D1600Cal(s_Adapter *p_HW, unsigned long ChipSelect);
unsigned long ADC12D1600Read(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address);
unsigned long ADC12D1600Write(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address, unsigned long Data);
unsigned long ADL5566Write(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long PortNumber, unsigned long Data);
unsigned long ADS42LB69Read(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address);
unsigned long ADS42LB69Write(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address, unsigned long Data);
unsigned long FXL6408Read(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address);
unsigned long FXL6408Write(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address, unsigned long Data);
unsigned long INA3221Read(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address);
unsigned long INA3221Write(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address, unsigned long Data);
unsigned long LTC1661Write(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address, unsigned long Data);
unsigned long LTC2991Read(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address);
unsigned long LTC2991Write(s_Adapter *p_HW, unsigned long ChipSelect, unsigned long Address, unsigned long Data);

#ifdef __cplusplus
}
#endif

#endif
